@@ -2,8 +2,8 @@ use strict;
 use warnings;
 package Getopt::Long::Descriptive;
 # ABSTRACT: Getopt::Long, but simpler and more powerful
-$Getopt::Long::Descriptive::VERSION = '0.106';
-use v5.10;
+$Getopt::Long::Descriptive::VERSION = '0.107';
+use v5.10.1;
 
 use Carp qw(carp croak);
 use File::Basename ();
@@ -291,12 +291,22 @@ our $MungeOptions = 1;
 
 our $TERM_WIDTH;
 {
-  if (eval { require Term::ReadKey; 1 }) {
-    my ($width) = Term::ReadKey::GetTerminalSize();
-    $TERM_WIDTH = $width;
-  } else {
-    $TERM_WIDTH = $ENV{COLUMNS} || 80;
-  }
+  $TERM_WIDTH = $ENV{COLUMNS} || 80;
+
+  # So, this was the old code:
+  #
+  #   if (eval { require Term::ReadKey; 1 }) {
+  #     my ($width) = Term::ReadKey::GetTerminalSize();
+  #     $TERM_WIDTH = $width;
+  #   } else {
+  #     $TERM_WIDTH = $ENV{COLUMNS} || 80;
+  #   }
+  #
+  # ...but the problem is that Term::ReadKey will carp when it can't get an
+  # answer, it can't be trivially made to keep quiet.  (I decline to stick a
+  # local $SIG{__WARN__} here, as it's too heavy a hammer.)  With the new (as
+  # of 2021-03) formatting code, using the full width is less of an issue,
+  # anyway.
 }
 
 sub _nohidden {
@@ -721,7 +731,7 @@ Getopt::Long::Descriptive - Getopt::Long, but simpler and more powerful
 
 =head1 VERSION
 
-version 0.106
+version 0.107
 
 =head1 SYNOPSIS
 
