@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Getopt::Long::Descriptive::Usage;
 # ABSTRACT: the usage description for GLD
-$Getopt::Long::Descriptive::Usage::VERSION = '0.106';
+$Getopt::Long::Descriptive::Usage::VERSION = '0.107';
 use List::Util qw(max);
 
 #pod =head1 SYNOPSIS
@@ -105,7 +105,7 @@ sub option_text {
 
     my $primary = shift @names;
     my $short;
-    my ($i) = grep {; length $names[$_] == 1 } keys @names;
+    my ($i) = grep {; length $names[$_] == 1 } (0 .. $#names);
     if (defined $i) {
       $short = splice @names, $i, 1;
     }
@@ -280,7 +280,7 @@ Getopt::Long::Descriptive::Usage - the usage description for GLD
 
 =head1 VERSION
 
-version 0.106
+version 0.107
 
 =head1 SYNOPSIS
 
